package com.ruoyi.ss.transactionBill.utils;

import com.ruoyi.ss.suit.domain.enums.SuitFeeMode;
import com.ruoyi.ss.suit.domain.enums.SuitFeeType;
import com.ruoyi.ss.suit.domain.enums.SuitTimeUnit;
import com.ruoyi.ss.transactionBill.domain.vo.TransactionBillVO;

import java.math.BigDecimal;
import java.math.RoundingMode;

/**
 * @author wjh
 * 2024/12/24
 */
public class RechargeUtils {

    /**
     * 转换为充值电量
     */
    public static BigDecimal toRechargeEle(TransactionBillVO bill) {
        if (bill == null) {
            return BigDecimal.ZERO;
        }
        // 计算周期数
        long round = calcRound(bill);
        return BigDecimal.valueOf(bill.getSuitTime() * round);
    }

    /**
     * 转换为充值秒
     */
    public static long toRechargeSeconds(TransactionBillVO bill) {
        long round = calcRound(bill);
        return toSecondSuitTime(bill) * round;
    }

    /**
     * 转换为套餐秒
     */
    public static long toSecondSuitTime(TransactionBillVO bill) {
        SuitTimeUnit unit = SuitTimeUnit.getByValue(bill.getSuitTimeUnit());
        if (unit == null) {
            unit = SuitTimeUnit.MINUTE;
        }
        long time = bill.getSuitTime() == null ? 0 : bill.getSuitTime();
        return time * unit.getConversion();
    }

    /**
     * 计算周期数
     */
    private static long calcRound(TransactionBillVO bill) {
        int round = 1;
        if (bill == null || bill.getSuitFeeMode() == null || bill.getSuitFeeType() == null) {
            return round;
        }
        // 若为智能单次，则计算出押金最大支持多少次，向上取整
        if (SuitFeeMode.SMART.getMode().equals(bill.getSuitFeeMode()) && SuitFeeType.singleList().contains(bill.getSuitFeeType())) {
            round = bill.getSuitDeposit().divide(bill.getSuitPrice(), 0, RoundingMode.UP).intValue();
        }
        return round;
    }

}
